@@ -393,7 +393,7 @@ class NDUCameraService(Thread):
             has_motion_kernel = self.__motion_kernel is not None
             results_for_preview = None
             for _frame_index, frame in self.video_source.get_frames():
-                if self.__result_handler.get_restart_required() or self.updater.exit_required:
+                if self.__result_handler.get_restart_required() or (self.updater is not None and self.updater.exit_required):
                     self._exit_requested = True
                     '''
                     try:
