@@ -8,7 +8,7 @@ from threading import Thread
 
 import paho.mqtt.client as mqttClient
 import yaml
-from ndu_gate_camera.utility import constants
+from ndu_gate_camera.utility import constants, ndu_utility
 from pathlib import Path
 from threading import Lock
 import requests
@@ -44,7 +44,8 @@ class ResultHandlerMqtt:
         self.save_lock = Lock()
         self.frame_lock = Lock()
         self.url = ""
-        self.http_topic = mqtt_obj.get("http_topic", "api/v1/")
+        self.http_url = mqtt_obj.get("http_url", "api/v1/")
+        ndu_utility.NDUUtility.host = self.host
         # Connect to ThingsBoard using default MQTT port and 60 seconds keepalive interval
         try:
             self.client.connect(host, mqtt_obj.get("port"), 5)
@@ -381,10 +382,7 @@ class ResultHandlerMqtt:
 
         try:
             self.save_frames_locally(frame, device)
-            if self.url == "":
-                r = requests.get("http://" + self.host)
-                self.url = r.url
-            response = requests.post(self.url + self.http_topic + self.access_token + "/attributes",
+            response = requests.post(self.http_url + self.access_token + "/attributes",
                                      headers=headers, data=data)
             # print(response)
         except Exception as e:
