@@ -102,7 +102,9 @@ def main(ndu_gate_config_file):
             result_hand_conf = DEFAULT_HANDLER_SETTINGS
 
         res_handler = result_hand_conf.get("type")
-        updater = Updater()
+        updater = None
+        if sys.platform == "win32":
+            updater = Updater()
         if str(res_handler) == str("SOCKET"):
             result_handler = ResultHandlerSocket(result_hand_conf.get("socket", {}),
                                                  result_hand_conf.get("device", None))
